Compute the Selective Maximum Likelihood Estimate for beta1
compute_MLE.RdThis function numerically approximates the conditional maximum likelihood estimate (MLE) of a single regression coefficient using a Monte Carlo approximation to the selective likelihood, conditional on passing the overall F-test.
Arguments
- X
A numeric matrix of predictor variables (n x p), with the first column corresponding to
beta1.- y
A numeric response vector of length n.
- alpha_ov
The significance level for the overall F-test (used in defining the selection region).
- B
The number of Monte Carlo samples used to approximate the likelihood (default:
1e6).- interval
A numeric vector of length 2 giving the search interval for
beta1(default:c(-10, 10)).